import '../internal.js';
import { Storages } from './storages.js';
export { Storages } from './storages.js';
import { Storage } from './storage.js';
import { defineConfig, removeProperties } from '@agile-ts/utils';
import { shared as sharedAgileInstance } from '../shared.js';
import { runsOnServer } from '../utils.js';
import { LogCodeManager } from '../logCodeManager.js';

let storageManager = null;
function createStorage(config) {
  return new Storage(config);
}
function createStorageManager(config = {}) {
  config = defineConfig(config, {
    agileInstance: sharedAgileInstance
  });
  return new Storages(config.agileInstance, removeProperties(config, ["agileInstance"]));
}
function getStorageManager() {
  if (storageManager == null) {
    const newStorageManager = createStorageManager({
      localStorage: !runsOnServer()
    });
    assignSharedAgileStorageManager(newStorageManager);
    return newStorageManager;
  }
  return storageManager;
}
const assignSharedAgileStorageManager = (instance) => {
  if (storageManager != null) {
    LogCodeManager.log("11:02:06", [], storageManager);
  }
  storageManager = instance;
};

export { assignSharedAgileStorageManager, createStorage, createStorageManager, getStorageManager };
